@@ -135,7 +135,7 @@
 "XVkbd*menu.close_display.label: Revert to Local Display",
 "XVkbd*menu.quit.label: Quit",
 "XVkbd*menu.SmeBSB.rightMargin: 30",
-"XVkbd*props_panel.title: xvkbd - proprety",
+"XVkbd*props_panel.title: xvkbd - property",
 "XVkbd*props_panel*defaultDistance: 10",
 "XVkbd*props_panel*vertDistance: 5",
 "XVkbd*props_panel*always_on_top.label: Always on Top?",
