@@ -110,8 +110,9 @@ struct appres_struct {
   float private_dict_decay;
   Boolean insert_blank_after_completion;
   Boolean integrate_completion_panel;
-} appres;
+};
 
+extern struct appres_struct appres;
 
 /* FindWidget() is defined in findwidget.c */
 extern Window FindWidget(Widget w, Window client, const char *name);
